@@ -24,8 +24,7 @@
 #define __GDICT_PREF_DIALOG_H__
 
 #include <gtk/gtk.h>
-
-#include "gdict.h"
+#include <libgdict/gdict.h>
 
 G_BEGIN_DECLS
 
@@ -37,24 +36,25 @@ G_BEGIN_DECLS
 #define GDICT_DEFAULT_PRINT_FONT 	"Serif 10"
 #define GDICT_DEFAULT_SOURCE_NAME 	"Default"
 
-#define GDICT_GCONF_DIR				"/apps/gnome-dictionary"
-#define GDICT_GCONF_DATABASE_KEY 		GDICT_GCONF_DIR "/database"
-#define GDICT_GCONF_STRATEGY_KEY 		GDICT_GCONF_DIR "/strategy"
-#define GDICT_GCONF_PRINT_FONT_KEY 		GDICT_GCONF_DIR "/print-font"
-#define GDICT_GCONF_SOURCE_KEY 			GDICT_GCONF_DIR "/source-name"
-#define GDICT_GCONF_WINDOW_WIDTH_KEY 		GDICT_GCONF_DIR "/default-window-width"
-#define GDICT_GCONF_WINDOW_HEIGHT_KEY 		GDICT_GCONF_DIR "/default-window-height"
-#define GDICT_GCONF_WINDOW_IS_MAXIMIZED_KEY 	GDICT_GCONF_DIR "/window-is-maximized"
+#define GDICT_SETTINGS_SCHEMA           "org.gnome.dictionary"
+#define GDICT_SETTINGS_PATH             "/org/gnome/dictionary"
+#define GDICT_SETTINGS_DATABASE_KEY 	"database"
+#define GDICT_SETTINGS_STRATEGY_KEY 	"strategy"
+#define GDICT_SETTINGS_PRINT_FONT_KEY 	"print-font"
+#define GDICT_SETTINGS_SOURCE_KEY 	"source-name"
 
-#define DOCUMENT_FONT_KEY 			"/desktop/gnome/interface/document_font_name"
+#define DESKTOP_SETTINGS_SCHEMA         "org.gnome.desktop.interface"
+#define DESKTOP_SETTINGS_PATH           "/desktop/gnome/interface"
+#define DOCUMENT_FONT_KEY               "document-font-name"
 
 typedef struct _GdictPrefDialog        GdictPrefDialog;
 typedef struct _GdictPrefDialogClass   GdictPrefDialogClass;
 
-GType      gdict_pref_dialog_get_type   (void) G_GNUC_CONST;
-GtkWidget *gdict_pref_dialog_new        (GtkWindow         *parent,
-				         const gchar       *title,
-				         GdictSourceLoader *loader);
+GType gdict_pref_dialog_get_type (void) G_GNUC_CONST;
+
+void gdict_show_pref_dialog (GtkWidget         *parent,
+			     const gchar       *title,
+			     GdictSourceLoader *loader);
 
 G_END_DECLS
 
